import * as stylis from 'stylis';
import { Stringifier } from '../types';
export type ICreateStylisInstance = {
    options?: {
        namespace?: string | undefined;
        prefix?: boolean | undefined;
    } | undefined;
    plugins?: stylis.Middleware[] | undefined;
};
export default function createStylisInstance({ options, plugins, }?: ICreateStylisInstance): Stringifier;
