/**
 * Convenience function for joining strings to form className chains
 */
export declare function joinStrings(a?: string | undefined, b?: string | undefined): string;
export declare function joinStringArray(arr: string[], sep?: string | undefined): string;
