import { DefaultTheme, ExecutionProps } from '../types';
export default function determineTheme(props: ExecutionProps, providedTheme?: DefaultTheme | undefined, defaultProps?: {
    theme?: DefaultTheme | undefined;
}): DefaultTheme | undefined;
