import { Interpolation, NoInfer, RuleSet, Styles } from '../types';
declare function css(styles: Styles<object>, ...interpolations: Interpolation<object>[]): RuleSet<object>;
declare function css<Props extends object>(styles: Styles<NoInfer<Props>>, ...interpolations: Interpolation<NoInfer<Props>>[]): RuleSet<NoInfer<Props>>;
export default css;
