import Keyframes from '../models/Keyframes';
import { Interpolation, Styles } from '../types';
export default function keyframes<Props extends object = {}>(strings: Styles<Props>, ...interpolations: Array<Interpolation<Props>>): Keyframes;
