import { IInlineStyleConstructor, StyleSheet } from '../types';
export declare const RN_UNSUPPORTED_VALUES: string[];
export declare const resetStyleCache: () => void;
/**
 * InlineStyle takes arbitrary CSS and generates a flat object
 */
export default function makeInlineStyleClass<Props extends object>(styleSheet: StyleSheet): IInlineStyleConstructor<Props>;
