import React from 'react';
import { ExecutionProps, Interpolation, Styles } from '../types';
export default function createGlobalStyle<Props extends object>(strings: Styles<Props>, ...interpolations: Array<Interpolation<Props>>): React.NamedExoticComponent<ExecutionProps & Props>;
