export declare const SC_ATTR: string;
export declare const SC_ATTR_ACTIVE = "active";
export declare const SC_ATTR_VERSION = "data-styled-version";
export declare const SC_VERSION: string;
export declare const SPLITTER = "/*!sc*/\n";
export declare const IS_BROWSER: boolean;
/**
 * True when running in a React Server Component environment (createContext
 * is unavailable). In browser / standalone / native builds the entire
 * expression is replaced with the literal `false` via rollup-plugin-replace
 * with empty delimiters (exact string match), enabling rollup constant
 * inlining and terser dead-code elimination for all RSC branches.
 */
export declare const IS_RSC: boolean;
export declare const DISABLE_SPEEDY: boolean;
export declare const STATIC_EXECUTION_CONTEXT: {};
